bl_info = {
    "name": "Solid Boot",
    "author": "Cosmo Mídias",
    "version": (1, 0, 1),
    "blender": (2, 80, 0),
    "location": "Preferences > Add-ons",
    "description": "3D Views loaded in Solid Mode rather Material Preview",
    "category": "3D View",
    "doc_url": "https://www.cosmomidias.com"
}

import bpy
import sys
from bpy.types import AddonPreferences

class SolidBootPreferences(AddonPreferences):
    bl_idname = __name__

    def draw(self, context):
        layout = self.layout
        # INFO TEXT
        
        box = layout.box()
        
        row = box.row(align=True)
        row.alignment = 'CENTER'
        row.label(text="When Blender starts or when new files are loaded Solid Boot will")
        
        row = box.row(align=True)
        row.alignment = 'CENTER'
        row.label(text=" automatically set all 3D views to Solid Mode rather Material Preview.")
        
        row = box.row(align=True)
        row.alignment = 'CENTER'
        row.label(text="No configuration needed. Just enable the addon and save the startup file.")

@bpy.app.handlers.persistent
def force_solid_view(dummy):
    wm = bpy.data.window_managers[0]
    for window in wm.windows:
        for area in window.screen.areas:
            if area.type == 'VIEW_3D':
                for space in area.spaces:
                    if space.type == 'VIEW_3D' and space.shading.type != 'WIREFRAME':
                        space.shading.type = 'SOLID'

def register():    
    # Check if handler isn't already registered
    if force_solid_view not in bpy.app.handlers.load_post:
        bpy.app.handlers.load_post.append(force_solid_view)
    
    bpy.utils.register_class(SolidBootPreferences)

def unregister():
    if force_solid_view in bpy.app.handlers.load_post:
        bpy.app.handlers.load_post.remove(force_solid_view)
    
    bpy.utils.unregister_class(SolidBootPreferences)
    
# For Blender 4.2+ extension system
if bpy.app.version >= (4, 2):
    from importlib import reload
    reload(sys.modules[__name__])

if __name__ == "__main__":
    register()